@@ -54,10 +54,10 @@ class Grader:
         assert isinstance(key_of_function, str)
         try:
             self.details[key_of_function] = key_of_function_val
-        except Exception as e:
-            print("Invalid function name value passed: ", e)
+        except Exception:
+            print("Invalid function name value passed")
 
-    def submit(self, email: str, token: str) -> bool:
+    def submit(self, email: str, token: str) -> dict:
         submission = {
             "assignmentKey": self.assignmentKey,
             "student_email": email,
@@ -73,8 +73,7 @@ class Grader:
 
             # get response form api
             response = request.json()
-            sys.stdout.write(response)
-            return True
+            return response["data"]
 
         except Exception:
-            return False
+            return {"err": "No live server found!"}
